@@ -19,9 +19,18 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_LANGUAGE_MANAGER_H__
-#define __GTK_SOURCE_LANGUAGE_MANAGER_H__
+#ifndef GTK_SOURCE_LANGUAGE_MANAGER_H
+#define GTK_SOURCE_LANGUAGE_MANAGER_H
 
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#  if defined (__GNUC__)
+#    warning "Only <gtksourceview/gtksource.h> can be included directly."
+#  elif defined (G_OS_WIN32)
+#    pragma message("Only <gtksourceview/gtksource.h> can be included directly.")
+#  endif
+#endif
+
+#include <glib-object.h>
 #include <gtksourceview/gtksourcetypes.h>
 
 G_BEGIN_DECLS
@@ -83,6 +92,9 @@ GtkSourceLanguage	 *gtk_source_language_manager_guess_language		(GtkSourceLangua
 										 const gchar		  *filename,
 										 const gchar		  *content_type);
 
+G_GNUC_INTERNAL
+GtkSourceLanguageManager *_gtk_source_language_manager_peek_default		(void);
+
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_LANGUAGE_MANAGER_H__ */
+#endif /* GTK_SOURCE_LANGUAGE_MANAGER_H */
