@@ -19,10 +19,19 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_MAP_H__
-#define __GTK_SOURCE_MAP_H__
+#ifndef GTK_SOURCE_MAP_H
+#define GTK_SOURCE_MAP_H
+
+#if !defined (GTK_SOURCE_H_INSIDE) && !defined (GTK_SOURCE_COMPILATION)
+#  if defined (__GNUC__)
+#    warning "Only <gtksourceview/gtksource.h> can be included directly."
+#  elif defined (G_OS_WIN32)
+#    pragma message("Only <gtksourceview/gtksource.h> can be included directly.")
+#  endif
+#endif
 
 #include <gtk/gtk.h>
+#include <gtksourceview/gtksourcetypes.h>
 #include <gtksourceview/gtksourceview.h>
 
 G_BEGIN_DECLS
@@ -35,8 +44,7 @@ G_BEGIN_DECLS
 #define GTK_SOURCE_IS_MAP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  GTK_SOURCE_TYPE_MAP))
 #define GTK_SOURCE_MAP_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  GTK_SOURCE_TYPE_MAP, GtkSourceMapClass))
 
-typedef struct _GtkSourceMap        GtkSourceMap;
-typedef struct _GtkSourceMapClass   GtkSourceMapClass;
+typedef struct _GtkSourceMapClass GtkSourceMapClass;
 
 struct _GtkSourceMap
 {
@@ -65,4 +73,4 @@ GtkSourceView		*gtk_source_map_get_view	(GtkSourceMap  *map);
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_MAP_H__ */
+#endif /* GTK_SOURCE_MAP_H */
